'use strict';

function verify ( message ) {
	var lines = message.split( '\n' );

	var capital = new RegExp( /^[A-Z]/ );

	if ( !capital.test( lines[ 0 ] ) ) {
		throw new Error( 'The first line of a commit message with a capital letter.' );
	}

	if ( lines[ 0 ].length < 30 ) {
		throw new Error( 'The first line in your commit message is too short.' );
	}

	if ( lines[ 0 ].length > 72 ) {
		throw new Error( 'The first line in your commit message is too long.' );
	}

	lines.forEach( function ( line, index ) {
		if ( line === '' ) {
			return;
		}

		var whitespace = new RegExp( /^\s/ );

		if ( whitespace.test( line ) ) {
			throw new Error( 'Lines cannot start with whitespace.' );
		}
	} );

	if ( lines.length > 1 ) {

		if ( lines[ 1 ] !== '' ) {
			throw new Error( 'Multiline messages need a line break after the first line.' );
		}

		var bullets = lines.splice( 2, lines.length );
		var dash    = new RegExp( /^- [A-Z]/ );

		bullets.forEach( function ( value, index ) {
			if ( !dash.test( value ) ) {
				throw new Error( 'Multiline messages need to start with a dash, space, and capital letter.' );
			}
		} );

	}

}

module.exports = verify;
