'use strict';

// Load core modules
var fs   = require( 'fs' );
var path = require( 'path' );

// Load other modules
var verify = require( '../lib/verify' );

require( 'should' );

function read ( file ) {
	return fs.readFileSync( path.join( __dirname, 'data', 'invalid', file ) + '.txt', 'utf8' );
}

var invalid = {
	'no-capital'    : read( 'no-capital' ),
	'no-dashstart'  : read( 'no-dashstart' ),
	'no-linebreak'  : read( 'no-linebreak' ),
	'no-whitespace' : read( 'no-whitespace' ),
	'not-formatted' : read( 'not-formatted' ),
	'too-long'      : read( 'too-long' ),
	'too-short'     : read( 'too-short' )
};

describe( 'Invalid commit messages', function () {

	it( 'should throw an error for being too short', function () {
		( function () {
			verify( invalid[ 'too-short' ] );
		} ).should.throw( 'The first line in your commit message is too short.' );
	} );

	it( 'should throw an error for being too long', function () {
		( function () {
			verify( invalid[ 'too-long' ] );
		} ).should.throw( 'The first line in your commit message is too long.' );
	} );

	it( 'should throw an error for not having a newline after the first', function () {
		( function () {
			verify( invalid[ 'no-linebreak' ] );
		} ).should.throw( 'Multiline messages need a line break after the first line.' );
	} );

	it( 'should throw an error for not having dashes for each line after two', function () {
		( function () {
			verify( invalid[ 'not-formatted' ] );
		} ).should.throw( 'Multiline messages need to start with a dash, space, and capital letter.' );
	} );

	it( 'should throw an error for starting with whitespace', function () {
		( function () {
			verify( invalid[ 'no-whitespace' ] );
		} ).should.throw( 'Lines cannot start with whitespace.' );
	} );

	it( 'should throw an error for starting with a dash', function () {
		( function () {
			verify( invalid[ 'no-dashstart' ] );
		} ).should.throw( 'The first line of a commit message with a capital letter.' );
	} );

	it( 'should throw an error for not starting with a capital letter', function () {
		( function () {
			verify( invalid[ 'no-capital' ] );
		} ).should.throw( 'The first line of a commit message with a capital letter.' );
	} );

} );
